@@ -1,9 +1,7 @@
-use crate::args::ArgSpec;
-use crate::{arg, arg_enum, args};
+use crate::prelude::*;
 use cdx::column::*;
-use cdx::util::{get_writer, Error, HeaderChecker, HeaderMode, Reader, Result, HEADER_MODE};
-use std::io::Write;
-use std::str::FromStr;
+use cdx::prelude::*;
+use cdx::util::{HeaderChecker, HeaderMode, HEADER_MODE};
 
 pub fn main(argv: &[String]) -> Result<()> {
     let prog = args::ProgSpec::new("Select columns", args::FileCount::Many);
@@ -15,7 +13,7 @@ pub fn main(argv: &[String]) -> Result<()> {
         arg_enum! {"header", "h", "Mode", "header requirements", &HEADER_MODE},
         arg_enum! {"dups", "D", "Mode", "Duplicate Column Handling", &["Fail", "Allow", "Numeric"]},
     ];
-    let (args, files) = args::parse(&prog, &A, argv);
+    let (args, files) = args::parse(&prog, &A, argv)?;
     let mut checker = HeaderChecker::new();
     let mut header = ColumnHeader::new();
     let mut v = Writer::new(b'\t');
