@@ -1,10 +1,6 @@
-use crate::arg;
-use crate::args;
-use crate::args::ArgSpec;
-use cdx::column::ColumnSet;
-use cdx::join::*;
-use cdx::text::Text;
-use cdx::util::{err, Error, Result};
+use crate::prelude::*;
+use cdx::join::{JoinConfig, NoMatch, OutColSpec};
+use cdx::prelude::*;
 
 pub fn main(argv: &[String]) -> Result<()> {
     let prog = args::ProgSpec::new("Join files on a matching column.", args::FileCount::Many);
@@ -14,7 +10,7 @@ pub fn main(argv: &[String]) -> Result<()> {
         arg! {"key", "k", "Spec", "How to compare lines"},
         arg! {"output", "o", "Spec", "Output columns : file.ColumnSet,file.ColumnSet"},
     ];
-    let (args, files) = args::parse(&prog, &A, argv);
+    let (args, files) = args::parse(&prog, &A, argv)?;
 
     let mut config = JoinConfig::new();
     config.infiles = files;
