@@ -1,22 +1,18 @@
-use crate::arg;
-use crate::args;
-use crate::args::ArgSpec;
-use cdx::comp::{comp_check, CompMaker, LineCompList};
+use crate::prelude::*;
+use cdx::comp::comp_check;
+use cdx::prelude::*;
 use cdx::sort;
-use cdx::text::Text;
-use cdx::util::{err, get_writer, Error, Reader, Result};
 
 pub fn main(argv: &[String]) -> Result<()> {
     let prog = args::ProgSpec::new("Sort lines.", args::FileCount::Many);
-    const A: [ArgSpec; 6] = [
+    const A: [ArgSpec; 5] = [
         arg! {"key", "k", "Spec", "How to compare adjacent lines"},
         arg! {"unique", "u", "", "Print only first of equal lines"},
         arg! {"merge", "m", "", "Merge already sorted files."},
-        arg! {"show-comp", "s", "", "Print available comparisons"},
         arg! {"check", "c", "", "Check to see if each input file is sorted."},
         arg! {"Check", "C", "Number", "Check to see if each input file is sorted. Report this many failures before exiting."},
     ];
-    let (args, files) = args::parse(&prog, &A, argv);
+    let (args, files) = args::parse(&prog, &A, argv)?;
 
     let mut unique = false;
     let mut merge = false;
@@ -38,9 +34,6 @@ pub fn main(argv: &[String]) -> Result<()> {
                 .to_usize_whole(x.value.as_bytes(), "number of reports")?;
         } else if x.name == "unique" {
             unique = true;
-        } else if x.name == "show-comp" {
-            CompMaker::help();
-            return Ok(());
         } else {
             unreachable!();
         }
