@@ -1,7 +1,5 @@
-use crate::args::ArgSpec;
-use crate::{arg, args};
-use cdx::text::Text;
-use cdx::util::Result;
+use crate::prelude::*;
+use cdx::prelude::*;
 
 pub fn main(argv: &[String]) -> Result<()> {
     let prog = args::ProgSpec::new("Transpose a file.", args::FileCount::One);
@@ -9,7 +7,7 @@ pub fn main(argv: &[String]) -> Result<()> {
         arg! {"head", "h", "",  "Add ' CDX' before first line."},
         arg! {"lines", "n", "Number",  "Maximum lines to examine."},
     ];
-    let (args, files) = args::parse(&prog, &A, argv);
+    let (args, files) = args::parse(&prog, &A, argv)?;
 
     let mut head = false;
     let mut lines = usize::MAX;
