@@ -1,14 +1,11 @@
 //! Handles conversion between named column sets and lists of column numbers
 //! Also helps with selecting those columns from a line of text
 
-use crate::expr::Expr;
 use crate::matcher::MatchMaker;
-use crate::text::Text;
-use crate::trans::TransList;
-use crate::util::{err, find_close, Error, Result, StringLine, TextLine};
+use crate::prelude::*;
+use crate::util::find_close;
 use std::collections::HashSet;
-use std::io::Write;
-use std::{fmt, str};
+use std::str;
 
 /// What to do if there would be duplicate column names
 #[derive(Debug, Copy, Clone)]
@@ -623,7 +620,7 @@ impl ColumnFun for ColumnWhole {
     }
     /// write the column values (called many times)
     fn write(&mut self, w: &mut dyn Write, line: &TextLine, _delim: u8) -> Result<()> {
-        w.write_all(&line.line[0..line.line.len() - 1])?;
+        w.write_all(&line.line()[0..line.line().len() - 1])?;
         Ok(())
     }
     /// resolve any named columns
